HttpStatus

Struct HttpStatus 

pub struct HttpStatus(pub u16);
HTTP status code.

Tuple Fields

0: u16

Implementations

Source

impl HttpStatus

pub const OK: HttpStatus

pub const ACCEPTED: HttpStatus

pub const BAD_REQUEST: HttpStatus

pub const UNAUTHORIZED: HttpStatus

pub const FORBIDDEN: HttpStatus

pub const NOT_FOUND: HttpStatus

pub const METHOD_NOT_ALLOWED: HttpStatus

pub const INTERNAL_SERVER_ERROR: HttpStatus

pub const SERVICE_UNAVAILABLE: HttpStatus

pub fn is_success(&self) -> bool

Returns true if this is a success status (2xx).

pub fn is_client_error(&self) -> bool

Returns true if this is a client error (4xx).

pub fn is_server_error(&self) -> bool

Returns true if this is a server error (5xx).