pub struct Stopwatch { /* private fields */ }Expand description
A stopwatch for measuring elapsed time with lap support.
Example
ⓘ
use fastmcp_rust::testing::prelude::*;
let mut stopwatch = Stopwatch::new();
// Do first operation
stopwatch.lap("operation_1");
// Do second operation
stopwatch.lap("operation_2");
println!("Total time: {:?}", stopwatch.elapsed());
for (name, duration) in stopwatch.laps() {
println!("{}: {:?}", name, duration);
}Implementations
Sourceimpl Stopwatch
impl Stopwatch
Sourcepub fn lap(&mut self, name: impl Into<String>)
pub fn lap(&mut self, name: impl Into<String>)
Records a lap with the given name.
The duration is measured from the last lap (or start if no laps).
Sourcepub fn since_last_lap(&self) -> Duration
pub fn since_last_lap(&self) -> Duration
Returns the time since the last lap (or start if no laps).
Sourcepub fn get_lap(&self, name: &str) -> Option<Duration>
pub fn get_lap(&self, name: &str) -> Option<Duration>
Returns the lap with the given name, if it exists.
Sourcepub fn total_lap_time(&self) -> Duration
pub fn total_lap_time(&self) -> Duration
Returns the sum of all lap durations.
Sourcepub fn stats(&self) -> TimingStats
pub fn stats(&self) -> TimingStats
Returns timing statistics.