pub struct HttpStatus(pub u16);Expand description
HTTP status code.
Tuple Fields
0: u16Implementations
Sourceimpl HttpStatus
impl HttpStatus
pub const OK: HttpStatus
pub const ACCEPTED: HttpStatus
pub const BAD_REQUEST: HttpStatus
pub const UNAUTHORIZED: HttpStatus
pub const FORBIDDEN: HttpStatus
pub const NOT_FOUND: HttpStatus
pub const METHOD_NOT_ALLOWED: HttpStatus
pub const INTERNAL_SERVER_ERROR: HttpStatus
pub const SERVICE_UNAVAILABLE: HttpStatus
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Returns true if this is a success status (2xx).
Sourcepub fn is_client_error(&self) -> bool
pub fn is_client_error(&self) -> bool
Returns true if this is a client error (4xx).
Sourcepub fn is_server_error(&self) -> bool
pub fn is_server_error(&self) -> bool
Returns true if this is a server error (5xx).