pub struct Codec { /* private fields */ }Expand description
Codec for encoding/decoding JSON-RPC messages.
Implementations
Sourceimpl Codec
impl Codec
Sourcepub fn max_message_size(&self) -> usize
pub fn max_message_size(&self) -> usize
Returns the maximum allowed message size in bytes.
Sourcepub fn set_max_message_size(&mut self, size: usize)
pub fn set_max_message_size(&mut self, size: usize)
Sets the maximum allowed message size in bytes.
Sourcepub fn encode_request(
&self,
request: &JsonRpcRequest,
) -> Result<Vec<u8>, CodecError>
pub fn encode_request( &self, request: &JsonRpcRequest, ) -> Result<Vec<u8>, CodecError>
Sourcepub fn encode_response(
&self,
response: &JsonRpcResponse,
) -> Result<Vec<u8>, CodecError>
pub fn encode_response( &self, response: &JsonRpcResponse, ) -> Result<Vec<u8>, CodecError>
Sourcepub fn decode(&mut self, data: &[u8]) -> Result<Vec<JsonRpcMessage>, CodecError>
pub fn decode(&mut self, data: &[u8]) -> Result<Vec<JsonRpcMessage>, CodecError>
Decodes bytes into a message, returning any complete messages.
Incomplete data is buffered for the next call.
Errors
Returns an error if a complete line fails to parse or if the buffer exceeds the limit.